from discord import ui, ButtonStyle, Interaction
from redbot.core import commands

from aurora.configuration.embed import embed
from aurora.configuration.utils import create_pagesize_options
from aurora.utilities.config import config

class Overrides(ui.View):
    def __init__(self, ctx: commands.Context):
        super().__init__()
        self.ctx = ctx

    @ui.button(label="Auto Evidence Format", style=ButtonStyle.green, row=0)
    async def auto_evidenceformat(self, interaction: Interaction, button: ui.Button): # pylint: disable=unused-argument
        if self.ctx.author != interaction.user:
            await interaction.response.send_message("You cannot change this setting for other users.", ephemeral=True)
            return
        await interaction.response.defer()
        current_setting = await config.user(self.ctx.author).auto_evidenceformat()
        if current_setting is not None:
            await config.user(self.ctx.author).auto_evidenceformat.set(not current_setting)
        else:
            await config.user(self.ctx.author).auto_evidenceformat.set(True)
        await interaction.message.edit(embed=await embed(self.ctx))

    @ui.button(label="X", style=ButtonStyle.red, row=0)
    async def auto_evidenceformat_reset(self, interaction: Interaction, button: ui.Button): # pylint: disable=unused-argument
        if self.ctx.author != interaction.user:
            await interaction.response.send_message("You cannot change this setting for other users.", ephemeral=True)
            return
        await interaction.response.defer()
        await config.user(self.ctx.author).auto_evidenceformat.clear()
        await interaction.message.edit(embed=await embed(self.ctx))

    @ui.button(label="Ephemeral", style=ButtonStyle.green, row=0)
    async def ephemeral(self, interaction: Interaction, button: ui.Button): # pylint: disable=unused-argument
        if self.ctx.author != interaction.user:
            await interaction.response.send_message("You cannot change this setting for other users.", ephemeral=True)
            return
        await interaction.response.defer()
        current_setting = await config.user(self.ctx.author).history_ephemeral()
        if current_setting:
            await config.user(self.ctx.author).history_ephemeral.set(not current_setting)
        else:
            await config.user(self.ctx.author).history_ephemeral.set(True)
        await interaction.message.edit(embed=await embed(self.ctx))

    @ui.button(label="X", style=ButtonStyle.red, row=0)
    async def ephemeral_reset(self, interaction: Interaction, button: ui.Button): # pylint: disable=unused-argument
        if self.ctx.author != interaction.user:
            await interaction.response.send_message("You cannot change this setting for other users.", ephemeral=True)
            return
        await interaction.response.defer()
        await config.user(self.ctx.author).history_ephemeral.clear()
        await interaction.message.edit(embed=await embed(self.ctx))

    @ui.button(label="Inline", style=ButtonStyle.green, row=0)
    async def inline(self, interaction: Interaction, button: ui.Button): # pylint: disable=unused-argument
        if self.ctx.author != interaction.user:
            await interaction.response.send_message("You cannot change this setting for other users.", ephemeral=True)
            return
        await interaction.response.defer()
        current_setting = await config.user(self.ctx.author).history_inline()
        if current_setting:
            await config.user(self.ctx.author).history_inline.set(not current_setting)
        else:
            await config.user(self.ctx.author).history_inline.set(True)
        await interaction.message.edit(embed=await embed(self.ctx))

    @ui.button(label="X", style=ButtonStyle.red, row=0)
    async def inline_reset(self, interaction: Interaction, button: ui.Button): # pylint: disable=unused-argument
        if self.ctx.author != interaction.user:
            await interaction.response.send_message("You cannot change this setting for other users.", ephemeral=True)
            return
        await interaction.response.defer()
        await config.user(self.ctx.author).history_inline.clear()
        await interaction.message.edit(embed=await embed(self.ctx))

    @ui.select(placeholder="Inline Pagesize", options=create_pagesize_options(), row=1)
    async def inline_pagesize(self, interaction: Interaction, select: ui.Select,): # pylint: disable=unused-argument
        if self.ctx.author != interaction.user:
            await interaction.response.send_message("You cannot change this setting for other users.", ephemeral=True)
            return
        await interaction.response.defer()
        await config.user(self.ctx.author).history_inline_pagesize.set(int(select.values[0]))
        await interaction.message.edit(embed=await embed(self.ctx))

    @ui.button(label="X", style=ButtonStyle.red, row=1)
    async def inline_pagesize_reset(self, interaction: Interaction, button: ui.Button): # pylint: disable=unused-argument
        if self.ctx.author != interaction.user:
            await interaction.response.send_message("You cannot change this setting for other users.", ephemeral=True)
            return
        await interaction.response.defer()
        await config.user(self.ctx.author).history_inline_pagesize.clear()
        await interaction.message.edit(embed=await embed(self.ctx))

    @ui.select(placeholder="Pagesize", options=create_pagesize_options(), row=2)
    async def pagesize(self, interaction: Interaction, select: ui.Select,): # pylint: disable=unused-argument
        if self.ctx.author != interaction.user:
            await interaction.response.send_message("You cannot change this setting for other users.", ephemeral=True)
            return
        await interaction.response.defer()
        await config.user(self.ctx.author).history_pagesize.set(int(select.values[0]))
        await interaction.message.edit(embed=await embed(self.ctx))

    @ui.button(label="X", style=ButtonStyle.red, row=2)
    async def pagesize_reset(self, interaction: Interaction, button: ui.Button): # pylint: disable=unused-argument
        if self.ctx.author != interaction.user:
            await interaction.response.send_message("You cannot change this setting for other users.", ephemeral=True)
            return
        await interaction.response.defer()
        await config.user(self.ctx.author).history_pagesize.clear()
        await interaction.message.edit(embed=await embed(self.ctx))
